@@ -150,6 +150,18 @@ uint ScreenCastPortal::CreateSession(const QDBusObjectPath &handle,
 
     if (!WaylandIntegration::isStreamingAvailable()) {
         qCWarning(XdgDesktopPortalKdeScreenCast) << "zkde_screencast_unstable_v1 does not seem to be available";
+        auto appName = Utils::applicationName(app_id);
+        Utils::warnNoStreaming({
+            .title = i18nc("@title:window", "Screen Sharing Not Available"),
+            .genericText = xi18nc("@info",
+                                  "The application <application>%1</application> tried to start a screen sharing session but screen sharing is not available "
+                                  "on this system. Please ensure you are running a Wayland session with a compatible window manager such as KWin.",
+                                  appName),
+            .x11Text = xi18nc("@info",
+                              "The application <application>%1</application> tried to start a screen sharing session but screen sharing is not available in "
+                              "X11 sessions. Please switch to a Wayland session and try again.",
+                              appName),
+        });
         return PortalResponse::OtherError;
     }
 
@@ -483,3 +495,5 @@ void ScreenCastSession::streamClosed()
         close();
     }
 }
+
+#include "moc_screencast.cpp"
